***********
Citing RAIL
***********

This code, while public on GitHub, has not yet been released by
DESC and is still under active development.  Our release of v1.0 will
be accompanied by a journal paper describing the development and
validation of `RAIL`.

If you make use of the ideas or software here, please cite this
repository ``https://github.com/LSSTDESC/RAIL``. You are welcome to
re-use the code, which is open source and available under terms
consistent with our `LICENSE
<https://github.com/LSSTDESC/RAIL/blob/master/LICENSE>`_ (`BSD 3-Clause
<https://opensource.org/licenses/BSD-3-Clause>`_).

External contributors and DESC members wishing to use RAIL for non-DESC projects
should consult with the Photometric Redshifts (PZ) Working Group conveners,
ideally before the work has started, but definitely before any publication or
posting of the work to the arXiv.

***********************************
Citing individual codes within RAIL
***********************************

Several of the codes included in RAIL are pre-existing codes written by external developers,
if these codes are used in an analysis they should be cited individually in addition to the
citation to RAIL.

Code references:

| Bayesian Photometric Redshifts (BPZ/BPZ_lite):
| `Benitez (2000) <https://ui.adsabs.harvard.edu/abs/2000ApJ...536..571B/abstract>`_
| `Coe et al (2006) <https://ui.adsabs.harvard.edu/abs/2006AJ....132..926C/abstract>`_

| Delight:
| `Leistedt & Hogg (2017) <https://ui.adsabs.harvard.edu/abs/2017ApJ...838....5L/abstract>`_

| FlexZBoost:
| `Izbicki & Lee (2017)
<https://projecteuclid.org/journals/electronic-journal-of-statistics/volume-11/issue-2/Converting-high-dimensional-regression-to-high-dimensional-conditional-density-estimation/10.1214/17-EJS1302.full>`_
| `Dalmasso et al (2020) <https://ui.adsabs.harvard.edu/abs/2020A%26C....3000362D/abstract>`_

| PZFlowPDF:
| J. F. Crenshaw (in prep)
| `Zenodo link <https://zenodo.org/record/6369625#.Ylcpjy-cYW8>`_

| trainZ:
| `Schmidt, Malz et al (2020) <https://ui.adsabs.harvard.edu/abs/2020MNRAS.499.1587S/abstract>`_
